@@ -110,6 +110,13 @@ DEVICES = [{
 SECTOR_START = 79267840
 SECTOR_END = 488265727
 SGDISK_LARGEST = "%s\n%s\n" % (SECTOR_START, SECTOR_END)
+SGDISK_V = """
+Problem: The secondary header's self-pointer indicates that it doesn't reside
+at the end of the disk. If you've added a disk to a RAID array, use the 'e'
+option on the experts' menu to adjust the secondary header's and partition
+table's locations.
+
+Identified 1 problems!"""
 
 # output of vgs --noheadings --options vg_name
 VGS = "  vg\n"
@@ -426,14 +433,14 @@ class TestGrowvols(base.BaseTestCase):
     def test_find_thin_pool(self, mock_execute):
         # No thin pool
         mock_execute.return_value = LVS
-        self.assertIsNone(growvols.find_thin_pool(DEVICES, 'vg'))
+        self.assertEqual((None, None), growvols.find_thin_pool(DEVICES, 'vg'))
         mock_execute.assert_called_once_with([
             'lvs', '--noheadings', '--options',
             'lv_name,lv_dm_path,lv_attr,pool_lv'])
 
         # One thin pool, all volumes use it
         mock_execute.return_value = LVS_THIN
-        self.assertEqual('/dev/mapper/vg-lv_thinpool',
+        self.assertEqual(('/dev/mapper/vg-lv_thinpool', 'lv_thinpool'),
                          growvols.find_thin_pool(DEVICES, 'vg'))
 
         # One pool, not used by all volumes
@@ -465,6 +472,9 @@ class TestGrowvols(base.BaseTestCase):
         # noop, only discover block device info
         mock_execute.side_effect = [
             LSBLK,
+            SGDISK_V,
+            '',
+            '',
             SGDISK_LARGEST,
             VGS,
             LVS,
@@ -473,6 +483,9 @@ class TestGrowvols(base.BaseTestCase):
         mock_execute.assert_has_calls([
             mock.call(['lsblk', '-Po',
                        'kname,pkname,name,label,type,fstype,mountpoint']),
+            mock.call(['sgdisk', '-v', '/dev/sda']),
+            mock.call(['sgdisk', '-e', '/dev/sda']),
+            mock.call(['partprobe']),
             mock.call(['sgdisk', '--first-aligned-in-largest',
                        '--end-of-largest', '/dev/sda']),
             mock.call(['vgs', '--noheadings', '--options', 'vg_name']),
@@ -484,6 +497,7 @@ class TestGrowvols(base.BaseTestCase):
         mock_execute.reset_mock()
         mock_execute.side_effect = [
             LSBLK,
+            '',
             SGDISK_LARGEST,
             VGS,
             LVS,
@@ -493,6 +507,7 @@ class TestGrowvols(base.BaseTestCase):
         mock_execute.assert_has_calls([
             mock.call(['lsblk', '-Po',
                        'kname,pkname,name,label,type,fstype,mountpoint']),
+            mock.call(['sgdisk', '-v', '/dev/sda']),
             mock.call(['sgdisk', '--first-aligned-in-largest',
                        '--end-of-largest', '/dev/sda']),
             mock.call(['vgs', '--noheadings', '--options', 'vg_name']),
@@ -512,6 +527,7 @@ class TestGrowvols(base.BaseTestCase):
         mock_execute.reset_mock()
         mock_execute.side_effect = [
             LSBLK,
+            '',
             SGDISK_LARGEST,
             VGS,
             LVS,
@@ -522,6 +538,7 @@ class TestGrowvols(base.BaseTestCase):
         mock_execute.assert_has_calls([
             mock.call(['lsblk', '-Po',
                        'kname,pkname,name,label,type,fstype,mountpoint']),
+            mock.call(['sgdisk', '-v', '/dev/sda']),
             mock.call(['sgdisk', '--first-aligned-in-largest',
                        '--end-of-largest', '/dev/sda']),
             mock.call(['vgs', '--noheadings', '--options', 'vg_name']),
@@ -549,6 +566,7 @@ class TestGrowvols(base.BaseTestCase):
         sgdisk_largest = "%s\n%s\n" % (sector_start, sector_end)
         mock_execute.side_effect = [
             LSBLK,
+            '',
             sgdisk_largest,
             VGS,
             LVS,
@@ -561,6 +579,7 @@ class TestGrowvols(base.BaseTestCase):
         # no space to grow, success
         mock_execute.side_effect = [
             LSBLK,
+            '',
             sgdisk_largest,
             VGS,
             LVS,
@@ -579,6 +598,7 @@ class TestGrowvols(base.BaseTestCase):
         mock_execute.reset_mock()
         mock_execute.side_effect = [
             LSBLK,
+            '',
             SGDISK_LARGEST,
             VGS,
             LVS_THIN,
@@ -589,6 +609,7 @@ class TestGrowvols(base.BaseTestCase):
         mock_execute.assert_has_calls([
             mock.call(['lsblk', '-Po',
                        'kname,pkname,name,label,type,fstype,mountpoint']),
+            mock.call(['sgdisk', '-v', '/dev/sda']),
             mock.call(['sgdisk', '--first-aligned-in-largest',
                        '--end-of-largest', '/dev/sda']),
             mock.call(['vgs', '--noheadings', '--options', 'vg_name']),
@@ -600,14 +621,14 @@ class TestGrowvols(base.BaseTestCase):
             mock.call(['pvcreate', '/dev/sda5']),
             mock.call(['vgextend', 'vg', '/dev/sda5']),
             mock.call(['lvextend', '--poolmetadatasize', '+1073741824B',
+                       'vg/lv_thinpool']),
+            mock.call(['lvextend', '-L+207253143552B',
                        '/dev/mapper/vg-lv_thinpool', '/dev/sda5']),
-            mock.call(['lvextend', '-L+208326885376B',
-                       '/dev/mapper/vg-lv_thinpool', '/dev/sda5']),
-            mock.call(['lvextend', '--size', '+41662021632B',
+            mock.call(['lvextend', '--size', '+41448112128B',
                        '/dev/mapper/vg-lv_home']),
-            mock.call(['lvextend', '--size', '+83328237568B',
+            mock.call(['lvextend', '--size', '+82900418560B',
                        '/dev/mapper/vg-lv_var']),
-            mock.call(['lvextend', '--size', '+83336626176B',
+            mock.call(['lvextend', '--size', '+82904612864B',
                        '/dev/mapper/vg-lv_root']),
             mock.call(['xfs_growfs', '/dev/mapper/vg-lv_home']),
             mock.call(['xfs_growfs', '/dev/mapper/vg-lv_var']),
